#
# spec file for package dar
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dar
Version:        2.4.18
Release:        3.3
Summary:        Backup and Restore Application
License:        SUSE-GPL-2.0+-with-openssl-exception
Group:          System/Filesystems
Url:            http://dar.linux.free.fr/
Source0:        http://sourceforge.net/projects/dar/files/dar/%{version}/%{name}-%{version}.tar.gz
Source1:        http://dar.linux.free.fr/sign/v%{version}/%{name}-%{version}.tar.gz.sig
Source2:        %{name}.keyring
Source3:        %{name}.changes
Patch2:         dar-use-libc-xattr.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  e2fsprogs-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools
BuildRequires:  libattr-devel
BuildRequires:  libbz2-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libtool
BuildRequires:  lzo-devel
BuildRequires:  openssl-devel
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
Recommends:     par
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%ifarch %ix86 x86_64 ppc
BuildRequires:  upx
%endif

%description
Dar (Disk Archive) is a hardware-independent backup solution. Dar uses
catalogs (unlike tar),which it makes it possible to extract a single
file without having to read the entire archive. It is also possible to
create incremental backups. Dar archives can also be created or used
with the libdar library (for example, with KDar, a KDE application).
This package contains the command line tools and documentation.

%package -n libdar5000
Summary:        Backup and Restore Application
Group:          System/Libraries
# We recommend the -lang pack from the library, as the lib itself is also gettextized. The main pack does
# not need the Recommends, as it requires the lib anyway (thus indirectyl Recommends the -lang package).
Recommends:     %{name}-lang
Provides:       libdar = 2.3.10
Obsoletes:      libdar < 2.3.10
# Package renamed to libdar4, according the shared library policy (2012-07-06) during openSUSE 12.2 cycle.
Provides:       libdar-4 = 2.3.10
Obsoletes:      libdar-4 < 2.3.10
# Package renamed to libdar5000, following so name change
Provides:       libdar4 = %{version}
Obsoletes:      libdar4 < %{version}

%description -n libdar5000
Dar stands for Disk ARchive and is a hardware independent backup
solution. Dar uses catalogs (unlike tar), so it is possible to extract
a single file without having to read the whole archive, and it is also
possible to create incremental backups.

Dar archives can also be created, or used, via the libdar library (for
example with KDar, a KDE application).

This package contains the library used by Dar and KDar.

%package -n libdar-devel
Summary:        Backup and Restore Application
Group:          Development/Languages/C and C++
Requires:       glibc-devel
Requires:       libbz2-devel
Requires:       libdar5000 = %{version}
Requires:       openssl-devel
Requires:       zlib-devel

%description -n libdar-devel
Dar stands for Disk ARchive and is a hardware independent backup
solution. Dar uses catalogs (unlike tar), so it is possible to extract
a single file without having to read the whole archive, and it is also
possible to create incremental backups.

Dar archives can also be created, or used, via the libdar library (with
KDar, a KDE application, for example).

This package contains the library used by Dar and KDar.

%lang_package

%prep
%setup -q
%patch2 -p1
%if 0%{?suse_version} > 1200
sed -i -e 's,^AM_GNU_GETTEXT_VERSION.*,-AM_GNU_GETTEXT_VERSION(0.18),' configure.ac
%else
# sle 11
sed -i -e 's,^AM_GNU_GETTEXT_VERSION.*,-AM_GNU_GETTEXT_VERSION(0.17),' configure.ac
%endif
# remove _DATE_ and _TIME_ macros
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{SOURCE3}")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
find .  -name '*.?pp' |\
    xargs sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g"

%build
autoreconf -f -i -v
%configure \
	--with-pic --datadir=%{_defaultdocdir} \
	--disable-static \
	--enable-largefile \
	--disable-dar-static
make %{?_smp_mflags}

%check
# ensure that dynamic linked binaries get installed
file %{buildroot}%{_bindir}/* | grep -q dynamic || exit 1
file %{buildroot}%{_bindir}/* | grep -q static && exit 1

%install
%if 0%{?suse_version} > 1200
%make_install
%else
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%endif
# libtool make executables static during installation
# overwrite them with original dynamic linked binaries
install -m 0755 src/dar_suite/.libs/* %{buildroot}%{_bindir}/
find %{buildroot} -type f -name "*.la" -delete -print

# Move the sample scripts to the correct location (otherwise rpmlint will error due to these scripts having execute perms)
mkdir %{buildroot}/%{_defaultdocdir}/%{name}/examples/
mv %{buildroot}/%{_defaultdocdir}/%{name}/samples/* %{buildroot}/%{_defaultdocdir}/%{name}/examples
%fdupes %{buildroot}%{_defaultdocdir}/%{name}
%find_lang %{name}

%post -n libdar5000 -p /sbin/ldconfig

%postun -n libdar5000 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS TODO ChangeLog
%{_bindir}/*
%{_mandir}/man1/*

%files lang -f %{name}.lang
%defattr(-,root,root)

%files -n libdar5000
%defattr(-,root,root)
%{_libdir}/libdar.so.*
%config(noreplace) %{_sysconfdir}/darrc

%files -n libdar-devel
%defattr(-,root,root)
%{_includedir}/%{name}/
%{_libdir}/libdar.so
%{_libdir}/pkgconfig/libdar*.pc

%changelog
* Sat Sep 19 2015 mpluskal@suse.com
- Update to 2.4.18
  * Initial Vector used for strong encryption was set with
    pseudo-random data generated using SHA1 message digest and
    blowfish cipher, which are not available when ligcrypt is
    running in FIPS mode. Since 2.4.18 we now use SHA256 and AES256
    for IV assignment in order to have libdar compatible with FIPS
    mode. For data encryption nothing changes: the cipher specified
    (-K, -J, -$ options on CLI) are used as before.
  * fixing bug met when performing archive isolation in
    sequential-read mode, If an archive corruption or truncated
    archive leads an inode to not have its CRC readable, dar aborts
    and issues a BUG report.
* Sat Mar  7 2015 mpluskal@suse.com
- Use SOURCE instead of %%{_sourcedir}/%%{name}.changes
* Tue Mar  3 2015 mpluskal@suse.com
- Add changelog to sources (necessary for _DATE_ and _TIME_
  macros substitution removal)
* Sun Mar  1 2015 mpluskal@suse.com
- Cleanup spec-file with spec-cleaner
- Use url for source
- Add gpg signature
- Get rid of _DATE_ and _TIME macros
- Update to 2.4.17
  * fixing issue when case insensitive comparison was requested
    and invalid wide char for the current local was met in a
    filename. In such situation the corresponding file was never
    saved before (considering a filesystem error for that file),
    while now the ASCII case insensitivity is used as fallback.
* Sun Jan 18 2015 Led <ledest@gmail.com>
- update to version 2.4.16
  * Extensive changelog can be found in Changelog file
- drop dar-2.4.14-fix-bashisms.patch (fixed in package itself)
* Sun Nov 16 2014 Led <ledest@gmail.com>
- fix bashisms in example scripts
- add patches:
  * dar-2.4.14-fix-bashisms.patch
* Thu Jun 26 2014 zawel1@gmail.com
- update to version 2.4.14
  * Extensive changelog can be found in Changelog file
- drop dar-DARWIN.patch (fixed in package itself)
* Sat Jun 14 2014 tchvatal@suse.com
- Drop unused patch dar.diff. Is replaced by sed in spec.
* Mon Jun  2 2014 crrodriguez@opensuse.org
- Also drop libattr from the -devel package requires
* Mon Jun  2 2014 crrodriguez@opensuse.org
- dar-use-libc-xattr.patch  extended attribute functions
  live in glibc, since approx 10 years and have to be used
  instead of those in libattr whenever the rest of its api is
  not used.
* Mon Aug 19 2013 adrian@suse.de
- fix build with old gettext (SLE 11)
* Mon Aug 19 2013 adrian@suse.de
- enforce and test for dynamic linking. (bnc#835318)
* Mon Jun  3 2013 adrian@suse.de
- update to version 2.4.10
  * Extensive changelog can be found in Changelog file
- enable lzo compression support
- enable strong encryption support via gcrypt
- rename lib package to follow so name change
* Mon Jul  9 2012 cfarrell@suse.com
- license update: SUSE-GPL-2.0+-with-openssl-exception
  The developers of dar included a special exception to link against
  openSSL
* Fri Jul  6 2012 dimstar@opensuse.org
- Remove libdar Requires from the devel package: it's not needed.
  Note: this did not cause any issue, as libdar4 provide libdar as
  a symbol.
- Package AUTHORS COPYING NEWS TODO ChangeLog as normal %%doc files,
  without copying them around first.
- Rename libdar-4 subpackage to libdar4, following the SLPP. Change
  the rpm group of libdar to System/Libraries.
- Create a -lang package, which is Recommended by libdar. This
  actually helps in the future when libdar5 would ever come out.
  Currently, due to the language files being part of the library
  package, it would be impossible to install multiple versions.
- Pass --disable-static to configure: no need to build it. And as
  a result, we also do not have to delete it in install again.
- Add fdupes BuildRequires and use it in %%install to link the same
  files together.
- Run spec-cleaner.
* Fri Jul  6 2012 dimstar@opensuse.org
- Add dar-DARWIN.patch: Fix the generation of the installed
  config.h header. Our autotools create a config.h.in which also
  contains #ifned _DARWIN_*, which is matched by the upstream grep
  command, but the matching #endif is not matched... See discussion
  and debug on http://lists.opensuse.org/opensuse-packaging/2012-07/msg00042.html.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Tue Aug  2 2011 aj@suse.de
- Fix filelist.
* Fri Sep  3 2010 tkedwards@fastmail.com.au
- Build for dar 2.3.10
-from 2.3.6 to 2.3.7:
- fixed bug in dar_manager
- fixed a bug in the statistics calculus of dar_manager
- fixed mistake in API tutorial
- fixed bug in the file filtering based on listing file ( -[ option )
- fixed typo and spelling errors in documentation
- from 2.3.7 to 2.3.8:
- fixed bug concerning elastic buffers used beside strong encryption
- added some speed optimizations
- from 2.3.8 to 2.3.9:
- very little optimization of the reading process of EA
- added -q option to dar
- added licensing exception to allow distribution of dar beside OpenSSL library
- Bug fix: during archive diff (only), dar restore atime of file in the backup
  instead of file in the system before opening it for reading.
- from 2.3.9 to 2.3.10:
- fixed bug in displaying dates [SF 2922417]
- enhanced pseudo-random number generation used in dar
* Tue Jan 13 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Sat Feb  2 2008 aj@suse.de
- Do not build test programs statically.
* Thu Jan 31 2008 aj@suse.de
- Remove check for old distribution.
- Remove duplicate files.
- Do not package .la files.
- Do not build dar-static to workaround glibc pthread linkage
  problem.
* Fri Jan 25 2008 adrian@suse.de
- fix open call with O_CREAT and without mode
* Fri Nov  9 2007 adrian@suse.de
- add missing #include
* Tue Nov  6 2007 adrian@suse.de
- fix building
- fix rpmlint errors
* Thu Nov  1 2007 coolo@suse.de
- compile with gcc 4.3
* Thu Nov  1 2007 coolo@suse.de
- update to 2.3.6
- changed displayed message when adding a hard link to an archive while
  performing a differential backup
- added back the possibility to use old blowfish implementation (bfw cipher)
- integrated optimization patch from Sonni Norlov
- updated Swedish translation by Peter Landgren
- updated French translation
- fixed broken Native Language Support in 2.3.x (where x<5)
  from 2.3.5 to 2.3.6
- fixed Makefile.am in src/dar_suite (removed "/" after $(DESTDIR))
- fixed bug in regex mask building when not using ordered masks
- fixing bug that led dar_manager to report no error while some files failed
  to be restored due to command-line for dar being too large.
- fixed bug met when user aborts operation while dar is finalizing archive creation [SF #1800507]
- fixed problem with execvp when dar_manager launches dar
* Fri Jul  6 2007 adrian@suse.de
- update to version 2.3.4
  * fixes a weakness in blowfish encryption (#289994)
  * hard link handling bugfix (2.3.3)
- rename libdar package to libdar-4
* Sun Jun 17 2007 ro@suse.de
- avoid string compare with char literal
* Mon Apr  2 2007 adrian@suse.de
- add libzz2-devel to BuildRequires
- fix dependencies of -devel package
* Sat Mar 31 2007 rguenther@suse.de
- add zlib-devel BuildRequires
* Tue Jan 16 2007 adrian@suse.de
- adding strong encryption support
- build with extended attributes support again (broken configure check)
* Tue Jan  9 2007 adrian@suse.de
- update to version 2.3.2 again (kdar seems to be dead and is dropped)
* Tue Nov 14 2006 adrian@suse.de
- initialize variable (#188286)
* Tue Oct 17 2006 dmueller@suse.de
- remove upx require
* Sun Sep 10 2006 dmueller@suse.de
- use RPM_OPT_FLAGS
* Mon Jul 10 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jul 10 2006 aj@suse.de
- Go back to version 2.2.6 since the only user of dar does not build
  with the new dar package.
* Thu May 18 2006 adrian@suse.de
- update to version 2.3.0 with lots of new features.
- added user_interaction::pause2() method
- added the snapshot feature
- added the Cache Directory Tagging detection feature
- adapted Wesley's patch for a pkgconfig for libdar
- added -[ and -] options (file selection from file listing)
  Important consequence for libdar user programs:
  the fs_root argument is now expanded to full absolute path inside libdar,
  thus the mask you will give for path inclusion/exclusion (the "subtree" argument)
  will be used against full absolute path of files under consideration
  for the operation. Assuming you have fs_root=tmp/A and the current
  directory is /tmp, your mask will be used against strings like
  /var/tmp/A/some/file. (instead of tmp/A/some/file as in the previous API
  version). Things are equal if the fs_root is given an absolute path.
- changed archive format to "05". Due to complete review of EA management.
- upon some signal reception, dar aborts the backup nicely, producing a
  completely formatted archive will all the file saved so far. This archive can
  be take as reference for a further backup to continue the operation at a later
  time.
- dar_manager aborts properly upon certain signal reception (do not let the database
  partially updated).
- dar_slave and dar_xform now recognize when a slicename is given in place of a basename
- reviewed thread_cancellation (API change) for it be possible to cancel several thread at the same time
- prevent some dead-lock situation that can occur when a signal is received inside a critical section
- dar_cp, dar_xform and dar_slave also abort nicely upon signal reception
- dar_manager can now restore files based on a given date (not always the most recent version)
- dar_manager now has an interactive mode (-i option)
- change in API, the warning() method need not be overwritten, but the new protected method
  inherited_warning() must be inherited in its place (same function, same prototype
  as the original warning() method).
- dar_manager features are now part of libdar. API has been completed with theses new features
- added the "last_slice" context (%%c with -E option) when creating an archive
- dar now check a file has not been modified while it was reading it, if so it reports a warning and returns a specific exit code
- remove included gettext from the package (it is more a source of conflict with external gettext and if somebody needs internationalization better is to install libintl/gettext on its own).
- added George Foot feedback about the good backup practice sort guide.
- added -e option to dar_manager
- added the progressive_report feature in the API
- dar can now pause every N slice where N >= 1
- integrated Dave Vasilevsky's patch to support Extended Attributes and file forks under MacOS X
- added method in API for external program be able to list dar_manager databases, their file contents and the statistics
- added the merge/sub-archive feature
- remove [list of path] from command line (-g option is now mandatory)
- added regex expression in filters (-ar/-ag options)
- added -ak option
- added the --comparison-field option (extension of the --ignore-owner option aka -O option)
- added the -af option (backup files more recent than a given date, others are keept as already saved)
- dar now take care that an escape character can be sent when pressing the arrow keys and avoid considering them in this situation
- dar will no refuse to abort if user presses escape when dar asks the user to be ready to write to a new slice
- adapted Wesley Legette's patch for an xml archive listing
- added 'InRef' status for EA (same meaning as the one for file's data)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 21 2006 cthiel@suse.de
- 2.2.6 update
* Mon Jan 16 2006 dmueller@suse.de
- 2.2.5 update
* Mon Sep 26 2005 mls@suse.de
- make libdar-devel package require base package
* Mon Jul 25 2005 mmj@suse.de
- fix build
* Fri Jul 15 2005 dmueller@suse.de
- 2.2.2 update
* Mon Apr 25 2005 adrian@suse.de
- fix compile on 64bit with gcc 4
* Mon Apr 11 2005 adrian@suse.de
- update to version 2.2.1
* Mon Jan 31 2005 adrian@suse.de
- update to version 2.2.0
  * thread safe lib
* Wed Nov 17 2004 adrian@suse.de
- update to version 2.1.5
  * gcc 3.4 support, -O1 workaround isn't needed anymore
* Thu Jul 15 2004 adrian@suse.de
- update to version 2.1.4
  * fixes ACL support (#42966)
* Sun Mar  7 2004 adrian@suse.de
- update to version 2.1.1
* Wed Feb 11 2004 adrian@suse.de
- update to final 2.1.0 version
* Sun Feb  8 2004 adrian@suse.de
- update to version 2.1.0_pre5
- optimise only with -O1, that fixes all missing symbol problems ...
* Tue Jan 13 2004 adrian@suse.de
- update to version 2.1.0_pre2
- fix compile issues
* Fri Jan  9 2004 adrian@suse.de
- support and require UPX compression on ia32
* Mon Jan  5 2004 adrian@suse.de
- initial package of version 2.0.4
